from setuptools import setup

setup(
    name='OpenPartsLibrary',
    version='0.1.0',    
    description='Python library for creating a database of hardware components for manufacturing',
    url='https://github.com/alekssadowski95/OpenPartsLibrary',
    author='Aleksander Sadowski',
    author_email='aleksander.sadowski@alsado.de',
    license='MIT',
    packages=['openpartslibrary'],
    install_requires=[''],

    classifiers=[
        'Development Status :: 1 - Planning',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: MIT License',  
        'Programming Language :: Python :: 3'
    ],
)
